# The name of the dashboard to be added to HORIZON['dashboards']. Required.
DASHBOARD = 'disaster_recovery'

# If set to True, this dashboard will not be added to the settings.
DISABLED = False

# A list of applications to be added to INSTALLED_APPS.
ADD_INSTALLED_APPS = [
    'disaster_recovery',
]



# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
#  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
#  License for the specific language governing permissions and limitations
#  under the License.

from django import shortcuts
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ungettext_lazy

from horizon import tables
from django.core.urlresolvers import reverse

import disaster_recovery.api.api as freezer_api


class DeleteAction(tables.DeleteAction):
    name = "delete"
    classes = ("btn-danger",)
    icon = "remove"
    help_text = _("Delete actions is not recoverable.")

    @staticmethod
    def action_present(count):
        return ungettext_lazy(
            u"Delete Action",
            u"Delete Actions",
            count
        )

    @staticmethod
    def action_past(count):
        return ungettext_lazy(
            u"Deleted Action",
            u"Deleted Actions",
            count
        )

    def delete(self, request, action_id):
        freezer_api.Action(request).delete(action_id)
        # TODO(m3m0): this shouldnt redirect here when an action is deleted
        # from jobs views
        return shortcuts.redirect('horizon:disaster_recovery:actions:index')


class DeleteMultipleActions(DeleteAction):
    name = "delete_multiple_actions"


class Filter(tables.FilterAction):
    filter_type = "server"
    filter_choices = (("exact", "Exact text", True),)


class CreateAction(tables.LinkAction):
    name = "create_action"
    verbose_name = _("Create Action")
    url = "horizon:disaster_recovery:actions:create"
    classes = ("ajax-modal",)
    icon = "plus"


class EditAction(tables.LinkAction):
    name = "edit_action"
    verbose_name = _("Edit")
    classes = ("ajax-modal",)
    icon = "pencil"

    def get_link_url(self, datum=None):
        return reverse("horizon:disaster_recovery:actions:create",
                       kwargs={'action_id': datum.action_id})


def get_link(action):
    return reverse('horizon:disaster_recovery:actions:action',
                   kwargs={'action_id': action.id})


class UpdateRow(tables.Row):
    ajax = True


class ActionsTable(tables.DataTable):
    backup_name = tables.Column('backup_name',

                                verbose_name=_("Action Name"),
                                link=get_link)
    action = tables.Column('action', verbose_name=_("Action"))
    path_to_backup = tables.Column('path_to_backup',
                                   verbose_name=_("Path To Backup or Restore"))
    storage = tables.Column('storage', verbose_name=_("Storage"))
    mode = tables.Column('mode', verbose_name=_("Mode"))

    class Meta:
        name = "actions_table"
        verbose_name = _("Actions")
        row_actions = (EditAction, DeleteAction,)
        table_actions = (Filter, CreateAction, DeleteMultipleActions)
        multi_select = True
        row_class = UpdateRow



# (c) Copyright 2014,2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.conf.urls import patterns
from django.conf.urls import url

from disaster_recovery.sessions import views


urlpatterns = patterns(
    '',

    url(r'^(?P<session_id>[^/]+)?$',
        views.SessionsView.as_view(),
        name='index'),

    url(r'^attach_to_session/(?P<job_id>[^/]+)?$',
        views.AttachToSessionWorkflow.as_view(),
        name='attach'),

    url(r'^create/$',
        views.CreateSessionWorkflow.as_view(),
        name='create'),

    url(r'^edit/(?P<session_id>[^/]+)?$',
        views.CreateSessionWorkflow.as_view(),
        name='edit'),

)



# (c) Copyright 2014,2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django import shortcuts
from django.utils.translation import ugettext_lazy as _
from django.utils.translation import ungettext_lazy

from horizon import tables
from horizon import messages
from django.core.urlresolvers import reverse

import disaster_recovery.api.api as freezer_api
from disaster_recovery.utils import shield


class ObjectFilterAction(tables.FilterAction):
    def allowed(self, request, datum):
        return bool(self.table.kwargs['job_id'])


class AttachJobToSession(tables.LinkAction):
    name = "attach_job_to_session"
    verbose_name = _("Attach To Session")
    classes = ("ajax-modal")
    url = "horizon:disaster_recovery:sessions:attach"

    def allowed(self, request, instance):
        return True

    def get_link_url(self, datum):
        return reverse("horizon:disaster_recovery:sessions:attach",
                       kwargs={'job_id': datum.job_id})


class DeleteJob(tables.DeleteAction):
    name = "delete"
    classes = ("btn-danger",)
    icon = "remove"
    help_text = _("Delete jobs is not recoverable.")

    @staticmethod
    def action_present(count):
        return ungettext_lazy(
            u"Delete Job File",
            u"Delete Job Files",
            count
        )

    @staticmethod
    def action_past(count):
        return ungettext_lazy(
            u"Deleted Job File",
            u"Deleted Job Files",
            count
        )

    @shield("Unable to delete job", redirect="jobs:index")
    def delete(self, request, job_id):
        return freezer_api.Job(request).delete(job_id)


class DeleteMultipleJobs(DeleteJob):
    name = "delete_multiple_jobs"


class CloneJob(tables.Action):
    name = "clone"
    verbose_name = _("Clone Job")
    help_text = _("Clone and edit a job file")

    @shield("Unable to clone job", redirect="jobs:index")
    def single(self, table, request, job_id):
        freezer_api.Job(request).clone(job_id)
        return shortcuts.redirect('horizon:disaster_recovery:jobs:index')


class EditJob(tables.LinkAction):
    name = "edit"
    verbose_name = _("Edit Job")
    classes = ("ajax-modal",)
    icon = "pencil"

    def get_link_url(self, datum=None):
        return reverse("horizon:disaster_recovery:jobs:edit_job",
                       kwargs={'job_id': datum.job_id})


class EditActionsInJob(tables.LinkAction):
    name = "edit_actions_in_job"
    verbose_name = _("Edit Actions")
    classes = ("ajax-modal",)
    icon = "pencil"

    def get_link_url(self, datum=None):
        return reverse("horizon:disaster_recovery:jobs:edit_action",
                       kwargs={'job_id': datum.job_id})


class StartJob(tables.Action):
    name = "start_job"
    verbose_name = _("Start Job")

    @shield("Unable to start job", redirect="jobs:index")
    def single(self, table, request, job_id):
        freezer_api.Job(request).start(job_id)
        messages.success(request, _("Job has started"))
        return shortcuts.redirect('horizon:disaster_recovery:jobs:index')

    def allowed(self, request, job=None):
        return True


class StopJob(tables.Action):
    name = "stop_job"
    verbose_name = _("Stop Job")

    @shield("Unable to stop job", redirect="jobs:index")
    def single(self, table, request, job_id):
        freezer_api.Job(request).stop(job_id)
        messages.success(request, _("Job has stopped"))
        return shortcuts.redirect('horizon:disaster_recovery:jobs:index')

    def allowed(self, request, job=None):
        if job.event == 'stop':
            return False
        return True


def get_link(row):
    return reverse('horizon:disaster_recovery:jobs:index',
                   kwargs={'job_id': row.job_id})


class CreateJob(tables.LinkAction):
    name = "create"
    verbose_name = _("Create Job")
    url = "horizon:disaster_recovery:jobs:create"
    classes = ("ajax-modal",)
    icon = "plus"


class UpdateRow(tables.Row):
    ajax = True


class JobsTable(tables.DataTable):
    job_name = tables.Column("description",
                             link=get_link,
                             verbose_name=_("Name"))

    client_id = tables.Column("client_id",
                              verbose_name=_("Host"))

    event = tables.Column("event",
                          verbose_name=_("Status"))

    result = tables.Column("result",
                           verbose_name=_("Result"))

    def get_object_id(self, row):
        return row.id

    class Meta(object):
        name = "jobs"
        verbose_name = _("Jobs")
        table_actions = (ObjectFilterAction,
                         CreateJob,
                         DeleteMultipleJobs)
        row_actions = (StartJob,
                       StopJob,
                       EditActionsInJob,
                       EditJob,
                       AttachJobToSession,
                       CloneJob,
                       DeleteJob)
        footer = False
        multi_select = True
        row_class = UpdateRow


class DeleteAction(tables.DeleteAction):
    name = "delete"
    classes = ("btn-danger",)
    icon = "remove"
    help_text = _("Delete actions is not recoverable.")

    @staticmethod
    def action_present(count):
        return ungettext_lazy(
            u"Delete Action",
            u"Delete Action",
            count
        )

    @staticmethod
    def action_past(count):
        return ungettext_lazy(
            u"Deleted action File",
            u"Deleted action Files",
            count
        )

    @shield("Unable to delete action", redirect="jobs:index")
    def delete(self, request, obj_id):
        freezer_api.Job(request).delete_action(obj_id)
        return reverse("horizon:disaster_recovery:jobs:index")


class DeleteMultipleActions(DeleteAction):
    name = "delete_multiple_actions"


class ActionsTable(tables.DataTable):
    action = tables.Column('action', verbose_name=_("Action Type"))

    name = tables.Column('backup_name', verbose_name=_("Action Name"))

    def get_object_id(self, container):
        # TODO(m3m0): we should't send the ids in this way
        ids = '{0}==={1}'.format(container.action_id, container.job_id)
        return ids

    class Meta(object):
        name = "actions_in_job"
        verbose_name = _("Actions")
        table_actions = (ObjectFilterAction,
                         DeleteMultipleActions)
        row_actions = (DeleteAction,)
        footer = False
        multi_select = True
